@@ -13,6 +13,12 @@ from coverage import env
 from coverage.files import abs_file
 
 
+skip_cpython_92236 = pytest.mark.skipif(
+    env.PYVERSION >= (3, 11, 0, "beta"),
+    reason="Avoid a CPython bug: https://github.com/python/cpython/issues/92236",
+    # #92236 is fixed in https://github.com/python/cpython/pull/92722
+)
+
 class SimpleArcTest(CoverageTest):
     """Tests for coverage.py's arc measurement."""
 
@@ -135,7 +141,7 @@ class SimpleArcTest(CoverageTest):
             assert foo() == 3 # 7
             """,
             arcz=".1 17 7.  .2 23 36 25 56 6.", arcz_missing="25 56"
-            )
+        )
         self.check_coverage("""\
             def foo():
                 if foo:
@@ -145,7 +151,7 @@ class SimpleArcTest(CoverageTest):
             foo() # 6
             """,
             arcz=".1 16 6.  .2 23 3. 25 5.", arcz_missing="25 5."
-            )
+        )
 
     def test_what_is_the_sound_of_no_lines_clapping(self):
         if env.JYTHON:
@@ -176,7 +182,7 @@ class SimpleArcTest(CoverageTest):
             """,
             arcz=".1 19 9-1  .2 23 27 34 47 56 67 7-1  9A A9",
             arcz_unpredicted="45",
-            )
+        )
 
 
 class WithTest(CoverageTest):
@@ -195,7 +201,7 @@ class WithTest(CoverageTest):
             example()
             """,
             arcz=arcz,
-            )
+        )
 
     def test_with_return(self):
         arcz = ".1 .2 23 34 4. 16 6."
@@ -210,7 +216,7 @@ class WithTest(CoverageTest):
             example()
             """,
             arcz=arcz,
-            )
+        )
 
     def test_bug_146(self):
         # https://github.com/nedbat/coveragepy/issues/146
@@ -225,7 +231,7 @@ class WithTest(CoverageTest):
             print(5)
             """,
             arcz=arcz,
-            )
+        )
 
     def test_nested_with_return(self):
         arcz = ".1 .2 23 34 45 56 6. 18 8."
@@ -242,7 +248,7 @@ class WithTest(CoverageTest):
             example(8)
             """,
             arcz=arcz,
-            )
+        )
 
     def test_break_through_with(self):
         arcz = ".1 12 23 34 45 15 5."
@@ -257,7 +263,7 @@ class WithTest(CoverageTest):
             """,
             arcz=arcz,
             arcz_missing="15",
-            )
+        )
 
     def test_continue_through_with(self):
         arcz = ".1 12 23 34 41 15 5."
@@ -271,7 +277,7 @@ class WithTest(CoverageTest):
             print(5)
             """,
             arcz=arcz,
-            )
+        )
 
     @pytest.mark.xfail(
         (3, 11) <= env.PYVERSION <= (3, 11, 0, 'alpha', 2, 0),
@@ -302,7 +308,7 @@ class WithTest(CoverageTest):
             arcz=arcz,
             arcz_missing=arcz_missing,
             arcz_unpredicted=arcz_unpredicted,
-            )
+        )
         expected = "line 3 didn't jump to the function exit"
         assert self.get_missing_arc_description(cov, 3, -2) == expected
 
@@ -328,7 +334,7 @@ class WithTest(CoverageTest):
             """,
             arcz=arcz,
             arcz_missing=arcz_missing,
-            )
+        )
         expected = "line 3 didn't jump to the function exit"
         assert self.get_missing_arc_description(cov, 3, -2) == expected
 
@@ -428,7 +434,7 @@ class LoopArcTest(CoverageTest):
             assert a == 4 and i == 3
             """,
             arcz=arcz,
-            )
+        )
 
     def test_while_true(self):
         # With "while True", 2.x thinks it's computation,
@@ -492,7 +498,7 @@ class LoopArcTest(CoverageTest):
                 break
             """,
             arcz=arcz
-            )
+        )
 
     def test_for_if_else_for(self):
         self.check_coverage("""\
@@ -519,7 +525,7 @@ class LoopArcTest(CoverageTest):
                 ".2 23 34 43 26 3. 6. " +
                 "-89 9A 9-8 AB BC CB B9 AE E9",
             arcz_missing="26 6."
-            )
+        )
 
     def test_for_else(self):
         self.check_coverage("""\
@@ -534,7 +540,7 @@ class LoopArcTest(CoverageTest):
             forelse([1,6])
             """,
             arcz=".1 .2 23 32 34 47 26 67 7. 18 89 9."
-            )
+        )
 
     def test_while_else(self):
         self.check_coverage("""\
@@ -605,6 +611,7 @@ class LoopArcTest(CoverageTest):
             arcz_missing="26 3. 6.",
         )
 
+    @skip_cpython_92236
     def test_generator_expression(self):
         # Generator expression:
         self.check_coverage("""\
@@ -617,6 +624,7 @@ class LoopArcTest(CoverageTest):
             arcz=".1 -22 2-2 12 23 34 45 53 3.",
         )
 
+    @skip_cpython_92236
     def test_generator_expression_another_way(self):
         # https://bugs.python.org/issue44450
         # Generator expression:
@@ -1169,6 +1177,7 @@ class ExceptionArcTest(CoverageTest):
 class YieldTest(CoverageTest):
     """Arc tests for generators."""
 
+    @skip_cpython_92236
     def test_yield_in_loop(self):
         self.check_coverage("""\
             def gen(inp):
@@ -1180,6 +1189,7 @@ class YieldTest(CoverageTest):
             arcz=".1 .2 23 2. 32 15 5.",
         )
 
+    @skip_cpython_92236
     def test_padded_yield_in_loop(self):
         self.check_coverage("""\
             def gen(inp):
@@ -1200,6 +1210,7 @@ class YieldTest(CoverageTest):
         env.PYVERSION[:5] == (3, 11, 0, 'alpha', 3),
         reason="avoid 3.11 bug: bpo46225",
     )
+    @skip_cpython_92236
     def test_bug_308(self):
         self.check_coverage("""\
             def run():
@@ -1234,10 +1245,7 @@ class YieldTest(CoverageTest):
             arcz=".1 14 45 54 4.  .2 2.  -22 2-2",
         )
 
-    @pytest.mark.skipif(
-        ((3, 11, 0, "alpha", 4, 0) == env.PYVERSION) and not env.C_TRACER,
-        reason="avoid a 3.11 bug: https://bugs.python.org/issue46389",
-    )
+    @skip_cpython_92236
     def test_bug_324(self):
         # This code is tricky: the list() call pulls all the values from gen(),
         # but each of them is a generator itself that is never iterated.  As a
@@ -1256,6 +1264,7 @@ class YieldTest(CoverageTest):
             arcz_missing="-33 3-3",
         )
 
+    @skip_cpython_92236
     def test_coroutines(self):
         self.check_coverage("""\
             def double_inputs():
@@ -1275,6 +1284,7 @@ class YieldTest(CoverageTest):
         )
         assert self.stdout() == "20\n12\n"
 
+    @skip_cpython_92236
     def test_yield_from(self):
         self.check_coverage("""\
             def gen(inp):
@@ -1290,6 +1300,7 @@ class YieldTest(CoverageTest):
             arcz=".1 19 9.  .2 23 34 45 56 63 37 7.",
         )
 
+    @skip_cpython_92236
     def test_abandoned_yield(self):
         # https://github.com/nedbat/coveragepy/issues/440
         self.check_coverage("""\
@@ -1618,10 +1629,7 @@ class MiscArcTest(CoverageTest):
         self.check_coverage(code, arcs=[(-1, 1), (1, 2*n+4), (2*n+4, -1)])
         assert self.stdout() == f"{n}\n"
 
-    @pytest.mark.skipif(
-        ((3, 11, 0, "alpha", 4, 0) == env.PYVERSION) and not env.C_TRACER,
-        reason="avoid a 3.11 bug: https://bugs.python.org/issue46389",
-    )
+    @skip_cpython_92236
     def test_partial_generators(self):
         # https://github.com/nedbat/coveragepy/issues/475
         # Line 2 is executed completely.
@@ -1785,7 +1793,7 @@ class LambdaArcTest(CoverageTest):
             b = 3
             """,
             arcz=".1 12 -22 2-2 23 3.", arcz_missing="-22 2-2",
-            )
+        )
 
     def test_raise_with_lambda_looks_like_partial_branch(self):
         self.check_coverage("""\
@@ -1838,6 +1846,7 @@ class AsyncTest(CoverageTest):
     """Tests of the new async and await keywords in Python 3.5"""
 
     @xfail_eventlet_670
+    @skip_cpython_92236
     def test_async(self):
         self.check_coverage("""\
             import asyncio
@@ -1865,6 +1874,7 @@ class AsyncTest(CoverageTest):
         assert self.stdout() == "Compute 1 + 2 ...\n1 + 2 = 3\n"
 
     @xfail_eventlet_670
+    @skip_cpython_92236
     def test_async_for(self):
         self.check_coverage("""\
             import asyncio
@@ -1940,6 +1950,7 @@ class AsyncTest(CoverageTest):
     # https://bugs.python.org/issue44621
     @pytest.mark.skipif(env.PYVERSION[:2] == (3, 9), reason="avoid a 3.9 bug: 44621")
     @pytest.mark.skipif(env.PYVERSION < (3, 7), reason="need asyncio.run")
+    @skip_cpython_92236
     def test_bug_1158(self):
         self.check_coverage("""\
             import asyncio
@@ -1970,6 +1981,7 @@ class AsyncTest(CoverageTest):
     )
     @xfail_eventlet_670
     @pytest.mark.skipif(env.PYVERSION < (3, 7), reason="need asyncio.run")
+    @skip_cpython_92236
     def test_bug_1176(self):
         self.check_coverage("""\
             import asyncio
