@@ -3,6 +3,7 @@
 
 """Test the config file handling for coverage.py"""
 
+import math
 from collections import OrderedDict
 
 from unittest import mock
@@ -10,7 +11,7 @@ import pytest
 
 import coverage
 from coverage.config import HandyConfigParser
-from coverage.exceptions import CoverageException, CoverageWarning
+from coverage.exceptions import ConfigError, CoverageWarning
 
 from tests.coveragetest import CoverageTest, UsingModulesMixin
 from tests.helpers import without_module
@@ -87,7 +88,7 @@ class ConfigTest(CoverageTest):
         assert cov.config.plugins == ["plugins.a_plugin"]
         assert cov.config.precision == 3
         assert cov.config.html_title == "tabblo & «ταБЬℓσ»"
-        assert round(abs(cov.config.fail_under-90.5), 7) == 0
+        assert math.isclose(cov.config.fail_under, 90.5)
         assert cov.config.get_plugin_options("plugins.a_plugin") == {"hello": "world"}
 
         # Test that our class doesn't reject integers when loading floats
@@ -97,7 +98,7 @@ class ConfigTest(CoverageTest):
             fail_under = 90
             """)
         cov = coverage.Coverage(config_file="pyproject.toml")
-        assert round(abs(cov.config.fail_under-90), 7) == 0
+        assert math.isclose(cov.config.fail_under, 90)
         assert isinstance(cov.config.fail_under, float)
 
     def test_ignored_config_file(self):
@@ -159,34 +160,31 @@ class ConfigTest(CoverageTest):
     def test_missing_rcfile_from_environment(self):
         self.set_environ("COVERAGE_RCFILE", "nowhere.ini")
         msg = "Couldn't read 'nowhere.ini' as a config file"
-        with pytest.raises(CoverageException, match=msg):
+        with pytest.raises(ConfigError, match=msg):
             coverage.Coverage()
 
-    def test_parse_errors(self):
-        # Im-parsable values raise CoverageException, with details.
-        bad_configs_and_msgs = [
-            ("[run]\ntimid = maybe?\n", r"maybe[?]"),
-            ("timid = 1\n", r"no section headers"),
-            ("[run\n", r"\[run"),
-            ("[report]\nexclude_lines = foo(\n",
-                r"Invalid \[report\].exclude_lines value 'foo\(': " +
-                r"(unbalanced parenthesis|missing \))"),
-            ("[report]\npartial_branches = foo[\n",
-                r"Invalid \[report\].partial_branches value 'foo\[': " +
-                r"(unexpected end of regular expression|unterminated character set)"),
-            ("[report]\npartial_branches_always = foo***\n",
-                r"Invalid \[report\].partial_branches_always value " +
-                r"'foo\*\*\*': " +
-                r"multiple repeat"),
-        ]
+    @pytest.mark.parametrize("bad_config, msg", [
+        ("[run]\ntimid = maybe?\n", r"maybe[?]"),
+        ("timid = 1\n", r"no section headers"),
+        ("[run\n", r"\[run"),
+        ("[report]\nexclude_lines = foo(\n",
+            r"Invalid \[report\].exclude_lines value 'foo\(': " +
+            r"(unbalanced parenthesis|missing \))"),
+        ("[report]\npartial_branches = foo[\n",
+            r"Invalid \[report\].partial_branches value 'foo\[': " +
+            r"(unexpected end of regular expression|unterminated character set)"),
+        ("[report]\npartial_branches_always = foo***\n",
+            r"Invalid \[report\].partial_branches_always value " +
+            r"'foo\*\*\*': " +
+            r"multiple repeat"),
+    ])
+    def test_parse_errors(self, bad_config, msg):
+        # Im-parsable values raise ConfigError, with details.
+        self.make_file(".coveragerc", bad_config)
+        with pytest.raises(ConfigError, match=msg):
+            coverage.Coverage()
 
-        for bad_config, msg in bad_configs_and_msgs:
-            print("Trying %r" % bad_config)
-            self.make_file(".coveragerc", bad_config)
-            with pytest.raises(CoverageException, match=msg):
-                coverage.Coverage()
-
-    @pytest.mark.parametrize("bad_config,msg", [
+    @pytest.mark.parametrize("bad_config, msg", [
         ("[tool.coverage.run]\ntimid = \"maybe?\"\n", r"maybe[?]"),
         ("[tool.coverage.run\n", None),
         ('[tool.coverage.report]\nexclude_lines = ["foo("]\n',
@@ -204,9 +202,9 @@ class ConfigTest(CoverageTest):
         ('[tool.coverage.report]\nfail_under="s"', "not a float"),
     ])
     def test_toml_parse_errors(self, bad_config, msg):
-        # Im-parsable values raise CoverageException, with details.
+        # Im-parsable values raise ConfigError, with details.
         self.make_file("pyproject.toml", bad_config)
-        with pytest.raises(CoverageException, match=msg):
+        with pytest.raises(ConfigError, match=msg):
             coverage.Coverage()
 
     def test_environment_vars_in_config(self):
@@ -363,13 +361,13 @@ class ConfigTest(CoverageTest):
     def test_tweak_error_checking(self):
         # Trying to set an unknown config value raises an error.
         cov = coverage.Coverage()
-        with pytest.raises(CoverageException, match="No such option: 'run:xyzzy'"):
+        with pytest.raises(ConfigError, match="No such option: 'run:xyzzy'"):
             cov.set_option("run:xyzzy", 12)
-        with pytest.raises(CoverageException, match="No such option: 'xyzzy:foo'"):
+        with pytest.raises(ConfigError, match="No such option: 'xyzzy:foo'"):
             cov.set_option("xyzzy:foo", 12)
-        with pytest.raises(CoverageException, match="No such option: 'run:xyzzy'"):
+        with pytest.raises(ConfigError, match="No such option: 'run:xyzzy'"):
             _ = cov.get_option("run:xyzzy")
-        with pytest.raises(CoverageException, match="No such option: 'xyzzy:foo'"):
+        with pytest.raises(ConfigError, match="No such option: 'xyzzy:foo'"):
             _ = cov.get_option("xyzzy:foo")
 
     def test_tweak_plugin_options(self):
@@ -378,12 +376,12 @@ class ConfigTest(CoverageTest):
         cov.set_option("run:plugins", ["fooey.plugin", "xyzzy.coverage.plugin"])
         cov.set_option("fooey.plugin:xyzzy", 17)
         cov.set_option("xyzzy.coverage.plugin:plugh", ["a", "b"])
-        with pytest.raises(CoverageException, match="No such option: 'no_such.plugin:foo'"):
+        with pytest.raises(ConfigError, match="No such option: 'no_such.plugin:foo'"):
             cov.set_option("no_such.plugin:foo", 23)
 
         assert cov.get_option("fooey.plugin:xyzzy") == 17
         assert cov.get_option("xyzzy.coverage.plugin:plugh") == ["a", "b"]
-        with pytest.raises(CoverageException, match="No such option: 'no_such.plugin:foo'"):
+        with pytest.raises(ConfigError, match="No such option: 'no_such.plugin:foo'"):
             _ = cov.get_option("no_such.plugin:foo")
 
     def test_unknown_option(self):
@@ -428,9 +426,9 @@ class ConfigTest(CoverageTest):
             branch = True
             """)
         config = HandyConfigParser("config.ini")
-        with pytest.raises(Exception, match="No section: 'xyzzy'"):
+        with pytest.raises(ConfigError, match="No section: 'xyzzy'"):
             config.options("xyzzy")
-        with pytest.raises(Exception, match="No option 'foo' in section: 'xyzzy'"):
+        with pytest.raises(ConfigError, match="No option 'foo' in section: 'xyzzy'"):
             config.get("xyzzy", "foo")
 
 
@@ -681,17 +679,13 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         assert cov.config.exclude_list == ["first", "✘weirdo", "third"]
         assert cov.config.html_title == "tabblo & «ταБЬℓσ» # numbers"
 
-    def test_unreadable_config(self):
+    @pytest.mark.parametrize("bad_file", ["nosuchfile.txt", "."])
+    def test_unreadable_config(self, bad_file):
         # If a config file is explicitly specified, then it is an error for it
         # to not be readable.
-        bad_files = [
-            "nosuchfile.txt",
-            ".",
-        ]
-        for bad_file in bad_files:
-            msg = "Couldn't read %r as a config file" % bad_file
-            with pytest.raises(CoverageException, match=msg):
-                coverage.Coverage(config_file=bad_file)
+        msg = f"Couldn't read {bad_file!r} as a config file"
+        with pytest.raises(ConfigError, match=msg):
+            coverage.Coverage(config_file=bad_file)
 
     def test_nocoveragerc_file_when_specified(self):
         cov = coverage.Coverage(config_file=".coveragerc")
@@ -714,7 +708,7 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         # Can't read a toml file that doesn't exist.
         with without_module(coverage.tomlconfig, 'tomli'):
             msg = "Couldn't read 'cov.toml' as a config file"
-            with pytest.raises(CoverageException, match=msg):
+            with pytest.raises(ConfigError, match=msg):
                 coverage.Coverage(config_file="cov.toml")
 
     def test_no_toml_installed_explicit_toml(self):
@@ -722,7 +716,7 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         self.make_file("cov.toml", "# A toml file!")
         with without_module(coverage.tomlconfig, 'tomli'):
             msg = "Can't read 'cov.toml' without TOML support"
-            with pytest.raises(CoverageException, match=msg):
+            with pytest.raises(ConfigError, match=msg):
                 coverage.Coverage(config_file="cov.toml")
 
     def test_no_toml_installed_pyproject_toml(self):
@@ -734,7 +728,7 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
             """)
         with without_module(coverage.tomlconfig, 'tomli'):
             msg = "Can't read 'pyproject.toml' without TOML support"
-            with pytest.raises(CoverageException, match=msg):
+            with pytest.raises(ConfigError, match=msg):
                 coverage.Coverage()
 
     def test_no_toml_installed_pyproject_no_coverage(self):
