@@ -11,6 +11,7 @@ from xml.etree import ElementTree
 import pytest
 
 import coverage
+from coverage.exceptions import NoDataError
 from coverage.files import abs_file
 from coverage.misc import import_local_file
 
@@ -22,11 +23,6 @@ from tests.helpers import assert_coverage_warnings, change_dir
 class XmlTestHelpers(CoverageTest):
     """Methods to use from XML tests."""
 
-    def run_mycode(self):
-        """Run mycode.py, so we can report on it."""
-        self.make_file("mycode.py", "print('hello')\n")
-        self.run_command("coverage run mycode.py")
-
     def run_doit(self):
         """Construct a simple sub-package."""
         self.make_file("sub/__init__.py")
@@ -98,34 +94,50 @@ class XmlTestHelpersTest(XmlTestHelpers, CoverageTest):
 class XmlReportTest(XmlTestHelpers, CoverageTest):
     """Tests of the XML reports from coverage.py."""
 
+    def make_mycode_data(self):
+        """Pretend that we ran mycode.py, so we can report on it."""
+        self.make_file("mycode.py", "print('hello')\n")
+        self.make_data_file(lines={abs_file("mycode.py"): [1]})
+
+    def run_xml_report(self, **kwargs):
+        """Run xml_report()"""
+        cov = coverage.Coverage()
+        cov.load()
+        cov.xml_report(**kwargs)
+
     def test_default_file_placement(self):
-        self.run_mycode()
-        self.run_command("coverage xml")
+        self.make_mycode_data()
+        self.run_xml_report()
         self.assert_exists("coverage.xml")
+        assert self.stdout() == ""
 
     def test_argument_affects_xml_placement(self):
-        self.run_mycode()
-        self.run_command("coverage xml -o put_it_there.xml")
+        self.make_mycode_data()
+        cov = coverage.Coverage(messages=True)
+        cov.load()
+        cov.xml_report(outfile="put_it_there.xml")
+        assert self.stdout() == "Wrote XML report to put_it_there.xml\n"
         self.assert_doesnt_exist("coverage.xml")
         self.assert_exists("put_it_there.xml")
 
-    def test_config_file_directory_does_not_exist(self):
-        self.run_mycode()
-        self.run_command("coverage xml -o nonexistent/put_it_there.xml")
+    def test_output_directory_does_not_exist(self):
+        self.make_mycode_data()
+        self.run_xml_report(outfile="nonexistent/put_it_there.xml")
         self.assert_doesnt_exist("coverage.xml")
         self.assert_doesnt_exist("put_it_there.xml")
         self.assert_exists("nonexistent/put_it_there.xml")
 
     def test_config_affects_xml_placement(self):
-        self.run_mycode()
+        self.make_mycode_data()
         self.make_file(".coveragerc", "[xml]\noutput = xml.out\n")
-        self.run_command("coverage xml")
+        self.run_xml_report()
         self.assert_doesnt_exist("coverage.xml")
         self.assert_exists("xml.out")
 
     def test_no_data(self):
         # https://github.com/nedbat/coveragepy/issues/210
-        self.run_command("coverage xml")
+        with pytest.raises(NoDataError, match="No data to report."):
+            self.run_xml_report()
         self.assert_doesnt_exist("coverage.xml")
 
     def test_no_source(self):
@@ -140,7 +152,7 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
         assert_coverage_warnings(
             warns,
             re.compile(r"Couldn't parse '.*innocuous.py'. \(couldnt-parse\)"),
-            )
+        )
         self.assert_exists("coverage.xml")
 
     def test_filename_format_showing_everything(self):
@@ -223,7 +235,7 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
         assert_coverage_warnings(
             warns,
             "Module not/really was never imported. (module-not-imported)",
-            )
+        )
         dom = ElementTree.parse("coverage.xml")
 
         self.assert_source(dom, "src/main")
@@ -259,6 +271,43 @@ class XmlReportTest(XmlTestHelpers, CoverageTest):
             self.start_import_stop(cov, "program")
             cov.xml_report()
 
+    def test_accented_dot_py(self):
+        # Make a file with a non-ascii character in the filename.
+        self.make_file("h\xe2t.py", "print('accented')")
+        self.make_data_file(lines={abs_file("h\xe2t.py"): [1]})
+        cov = coverage.Coverage()
+        cov.load()
+        cov.xml_report()
+        # The XML report is always UTF8-encoded.
+        with open("coverage.xml", "rb") as xmlf:
+            xml = xmlf.read()
+        assert ' filename="h\xe2t.py"'.encode() in xml
+        assert ' name="h\xe2t.py"'.encode() in xml
+
+    def test_accented_directory(self):
+        # Make a file with a non-ascii character in the directory name.
+        self.make_file("\xe2/accented.py", "print('accented')")
+        self.make_data_file(lines={abs_file("\xe2/accented.py"): [1]})
+
+        # The XML report is always UTF8-encoded.
+        cov = coverage.Coverage()
+        cov.load()
+        cov.xml_report()
+        with open("coverage.xml", "rb") as xmlf:
+            xml = xmlf.read()
+        assert b' filename="\xc3\xa2/accented.py"' in xml
+        assert b' name="accented.py"' in xml
+
+        dom = ElementTree.parse("coverage.xml")
+        elts = dom.findall(".//package[@name='â']")
+        assert len(elts) == 1
+        assert elts[0].attrib == {
+            "branch-rate": "0",
+            "complexity": "0",
+            "line-rate": "1",
+            "name": "â",
+        }
+
 
 def unbackslash(v):
     """Find strings in `v`, and replace backslashes with slashes throughout."""
@@ -302,7 +351,7 @@ class XmlPackageStructureTest(XmlTestHelpers, CoverageTest):
             ('package', {'name': "d0.d0"}),
             ('class', {'filename': "d0/d0/__init__.py", 'name': "__init__.py"}),
             ('class', {'filename': "d0/d0/f0.py", 'name': "f0.py"}),
-            ])
+        ])
 
     def test_package_depth_1(self):
         self.make_tree(width=1, depth=4)
@@ -323,7 +372,7 @@ class XmlPackageStructureTest(XmlTestHelpers, CoverageTest):
             ('class', {'filename': "d0/d0/d0/f0.py", 'name': "d0/d0/f0.py"}),
             ('class', {'filename': "d0/d0/f0.py", 'name': "d0/f0.py"}),
             ('class', {'filename': "d0/f0.py", 'name': "f0.py"}),
-            ])
+        ])
 
     def test_package_depth_2(self):
         self.make_tree(width=1, depth=4)
@@ -345,7 +394,7 @@ class XmlPackageStructureTest(XmlTestHelpers, CoverageTest):
             ('class', {'filename': "d0/d0/d0/__init__.py", 'name': "d0/__init__.py"}),
             ('class', {'filename': "d0/d0/d0/f0.py", 'name': "d0/f0.py"}),
             ('class', {'filename': "d0/d0/f0.py", 'name': "f0.py"}),
-            ])
+        ])
 
     def test_package_depth_3(self):
         self.make_tree(width=1, depth=4)
@@ -368,7 +417,7 @@ class XmlPackageStructureTest(XmlTestHelpers, CoverageTest):
             ('package', {'name': "d0.d0.d0"}),
             ('class', {'filename': "d0/d0/d0/__init__.py", 'name': "__init__.py"}),
             ('class', {'filename': "d0/d0/d0/f0.py", 'name': "f0.py"}),
-            ])
+        ])
 
     def test_source_prefix(self):
         # https://github.com/nedbat/coveragepy/issues/465
@@ -380,7 +429,7 @@ class XmlPackageStructureTest(XmlTestHelpers, CoverageTest):
         self.assert_package_and_class_tags(cov, [
             ('package', {'name': "."}),
             ('class', {'filename': "mod.py", 'name': "mod.py"}),
-            ])
+        ])
         dom = ElementTree.parse("coverage.xml")
         self.assert_source(dom, "src")
 
